# Movie ratings

Use collaborative filtering to create recommendations based on ratings from existing users. Set the filter to "training == 1" to predict ratings for movies 6-10 for user U11.

## Variables

* Users: Users 1-11
* Movies: Movies 1-10
* Rating: Movie rating on a 1-5 scale
* training: Training variable that is 0 for user U11 and 1 for all other users
